/* This file is part of the KDE desktop environment

   Copyright (C) 2001, 2002 Michael Brade <brade@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <qlayout.h>
#include <qpushbutton.h>

#include <kapp.h>
#include <kdebug.h>
#include <kpassivepopup.h>

#include "katalog.h"
#include "main.h"


KatalogTest::KatalogTest( QWidget *parent, const char *name )
  : QWidget( parent, name )
{
  k = new Katalog();
  k->initDocument( KURL("/home/stefano/test2.katalog"));

  QPushButton* start1 = new QPushButton( "Start listing 1", this );
  QPushButton* start2= new QPushButton( "Start listing 2", this );
  QPushButton* test = new QPushButton( "Many", this );

  QVBoxLayout* layout = new QVBoxLayout( this );
  
  layout->addWidget( start1 );
  layout->addWidget( start2 );
  layout->addWidget( test );
  resize( layout->sizeHint() );

  connect( start1, SIGNAL( clicked() ), SLOT( start1() ) );
  connect( start2, SIGNAL( clicked() ), SLOT( start2() ) );
  connect( test, SIGNAL( clicked() ), SLOT( test() ) );
}

KatalogTest::~KatalogTest()
{
  delete k;
}

void KatalogTest::start1()
{
  kdDebug() << k->addItems( KURL("csdcdsacasd"), "Archivio") << endl;
  kdDebug() << k->addItems( KURL("file:/home/stefano/aaaa"), "Archivio") << endl;
  kdDebug() << k->addItems( KURL("pippo:/home/stefano/"), "Archivio") << endl;
  kdDebug() << k->addItems( KURL("file:/home/stefano/img"), "") << endl;
  kdDebug() << k->addItems( KURL("file:/home/stefano/img"), "Immagini", 0L, true) << endl;
  connect( k, SIGNAL( finished() ), SLOT( slotFinished() ) );
}

void KatalogTest::start2()
{
  k->addItems( KURL("devices:/devsda1mntflash"), "Archivio 2");
  connect( k, SIGNAL( finished() ), SLOT( slotFinished() ) );
}

void KatalogTest::test()
{
}

void KatalogTest::slotFinished()
{
  kdDebug() << "SAVING\n";
  QStringList list;
  KPassivePopup::message("Finished !!!", this);
//  list.append("Immagini");
  kdDebug() << k->findEntry(list).isEmpty() << endl;
  kdDebug() << "SAVE" << k->saveDocument( KURL("/home/stefano/test8.katalog")) << endl;
  kdDebug() << k->saveDocument( KURL("/root/test2.katalog")) << endl;
}

int main ( int argc, char *argv[] )
{
  KApplication app( argc, argv, "kdirlistertest" );

  KatalogTest *test = new KatalogTest( 0 );
  test->show();
  app.setMainWidget( test );
  return app.exec();
}

#include "main.moc"
